Theming - Semantic

Add Friend
Title
Meta
One or two sentence description that may go to several lines
Arbitrary Arbitrary
Call to Action
Name
Date
Users
Like Favorite
Abbreviated Header
Action 1
Action 2
Cute Dog
Animals
Username
Action 1
Action 2
Action 3
Action 4
Content 1
Content 2
Content 3
Extra Content
Content 1
Content 2
Content 3
Extra Content
Content 1
Content 2
Content 3
Extra Content
Content 1
Content 2
Content 3
Extra Content